@@ -151,7 +151,7 @@ class Device(object):
             self._device = hidapi.hid_open_path(path)
         elif not (vendor_id is None or product_id is None):
             self._device = hidapi.hid_open(vendor_id, product_id,
-                                           serial_number)
+                                           serial_number or ffi.NULL)
         else:
             raise ValueError("Must provide either a DeviceInfo object, 'path' "
                              "or 'vendor_id' and 'product_id'.")
@@ -283,7 +283,7 @@ class Device(object):
         buf = ffi.buffer(bufp, len(data)+1)
         buf[0] = report_id
         buf[1:] = data
-        rv = hidapi.hid_send_feature_report(self._device, bufp, len(data))
+        rv = hidapi.hid_send_feature_report(self._device, bufp, len(bufp))
         if rv == -1:
             raise IOError("Failed to send feature report to HID device: {0}"
                           .format(self._get_last_error_string()))
